@@ -1,6 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2014 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -24,11 +25,17 @@ template <typename T, typename Tag>
 class INSPIRCD_INTRUSIVE_LIST_NAME
 {
  public:
-	class iterator : public std::iterator<std::bidirectional_iterator_tag, T*>
+	class iterator
 	{
 		T* curr;
 
 	 public:
+		typedef std::ptrdiff_t difference_type;
+		typedef std::bidirectional_iterator_tag iterator_category;
+		typedef T** pointer;
+		typedef T*& reference;
+		typedef T* value_type;
+
 		iterator(T* i = NULL)
 			: curr(i)
 		{
