@@ -2,9 +2,8 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2015 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2019, 2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -23,7 +22,9 @@
 
 #pragma once
 
-#ifdef __GNUC__
+#if defined __INTEL_COMPILER
+# pragma warning(disable:1478)
+#elif defined __GNUC__
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
@@ -155,7 +156,9 @@ class ServerEventListener
 	}
 };
 
-#ifdef __GNUC__
+#if defined __INTEL_COMPILER
+# pragma warning(enable:1478)
+#elif defined __GNUC__
 # pragma GCC diagnostic pop
 #endif
 
