@@ -1,6 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2015-2016 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -28,6 +29,37 @@ namespace Whois
 	class Context;
 }
 
+enum
+{
+	// InspIRCd-specific.
+	RPL_WHOISCOUNTRY = 344,
+	RPL_WHOISGATEWAY = 350,
+	RPL_CHANNELSMSG = 651,
+
+	// From ircu.
+	RPL_WHOISACCOUNT = 330,
+
+	// From oftc-hybrid.
+	RPL_WHOISCERTFP = 276,
+
+	// From RFC 1459.
+	RPL_WHOISUSER = 311,
+	RPL_WHOISSERVER = 312,
+	RPL_WHOISOPERATOR = 313,
+	RPL_WHOISIDLE = 317,
+	RPL_ENDOFWHOIS = 318,
+	RPL_WHOISCHANNELS = 319,
+
+	// From UnrealIRCd.
+	RPL_WHOISREGNICK = 307,
+	RPL_WHOISHELPOP = 310,
+	RPL_WHOISSPECIAL = 320,
+	RPL_WHOISBOT = 335,
+	RPL_WHOISHOST = 378,
+	RPL_WHOISMODES = 379,
+	RPL_WHOISSECURE = 671
+};
+
 class Whois::EventListener : public Events::ModuleEventListener
 {
  public:
@@ -74,9 +106,9 @@ class Whois::Context
 	User* const target;
 
  public:
-	Context(LocalUser* src, User* targ)
-		: source(src)
-		, target(targ)
+	Context(LocalUser* sourceuser, User* targetuser)
+		: source(sourceuser)
+		, target(targetuser)
 	{
 	}
 
