@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2018 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013-2014, 2016-2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2012-2014 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
@@ -59,7 +59,13 @@ struct FilePosition
 	FilePosition(const std::string& Name)
 		: name(Name)
 		, line(1)
-		, column(1)
+		, column(0)
+	{
+	}
+
+	FilePosition()
+		: line(0)
+		, column(0)
 	{
 	}
 
@@ -118,7 +124,7 @@ struct Parser
 	std::string mandatory_tag;
 
 	Parser(ParseStack& me, int myflags, FILE* conf, const std::string& name, const std::string& mandatorytag)
-		: stack(me), flags(myflags), file(conf), current(name), last_tag(name), ungot(-1), mandatory_tag(mandatorytag)
+		: stack(me), flags(myflags), file(conf), current(name), ungot(-1), mandatory_tag(mandatorytag)
 	{ }
 
 	int next(bool eof_ok = false)
@@ -157,9 +163,15 @@ struct Parser
 	{
 		while (1)
 		{
-			int ch = next();
+			int ch = next(true);
 			if (ch == '\n')
 				return;
+
+			if (ch == EOF)
+			{
+				unget(ch);
+				return;
+			}
 		}
 	}
 
@@ -401,9 +413,10 @@ struct Parser
 		{
 			stack.errstr << err.GetReason() << " at " << current.str();
 			if (tag)
-				stack.errstr << " (inside tag " << tag->tag << " at line " << tag->src_line << ")\n";
-			else
-				stack.errstr << " (last tag was on line " << last_tag.line << ")\n";
+				stack.errstr << " (inside <" << tag->tag << "> tag on line " << tag->src_line << ")";
+			else if (!last_tag.name.empty())
+				stack.errstr << " (last tag was on line " << last_tag.line << ")";
+			stack.errstr << " \n";
 		}
 		return false;
 	}
