@@ -1,10 +1,9 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2013, 2017, 2021 Sadie Powell <sadie@witchery.services>
- *   Copyright (C) 2012-2013, 2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2013, 2017, 2021-2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Matt Smith <dz@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
@@ -48,7 +47,7 @@ class ModuleAllowInvite : public Module
 			if (res == MOD_RES_DENY)
 			{
 				// Matching extban, explicitly deny /invite
-				user->WriteNumeric(ERR_CHANOPRIVSNEEDED, channel->name, "You are banned from using INVITE");
+				user->WriteNumeric(ERR_RESTRICTED, channel->name, "You are banned from using INVITE");
 				return res;
 			}
 			if (channel->IsModeSet(ni) || res == MOD_RES_ALLOW)
