@@ -7,7 +7,7 @@
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2007, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006-2007 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -26,12 +26,6 @@
 #include "inspircd.h"
 #include "modules/server.h"
 
-enum
-{
-	// From RFC 2182.
-	ERR_UNAVAILRESOURCE = 437
-};
-
 // The number of seconds the channel will be closed for.
 static unsigned int duration;
 
