@@ -1,13 +1,14 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2013, 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2022 delthas
+ *   Copyright (C) 2013, 2018-2020, 2022 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007 John Brooks <special@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2004, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2004 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -26,6 +27,7 @@
 #include "inspircd.h"
 #include "modules/ircv3.h"
 #include "modules/ircv3_replies.h"
+#include "modules/monitor.h"
 
 class CommandSetName : public SplitCommand
 {
@@ -71,11 +73,13 @@ class ModuleSetName : public Module
  private:
 	CommandSetName cmd;
 	ClientProtocol::EventProvider setnameevprov;
+	Monitor::API monitorapi;
 
  public:
 	ModuleSetName()
 		: cmd(this)
 		, setnameevprov(this, "SETNAME")
+		, monitorapi(this)
 	{
 	}
 
@@ -99,7 +103,8 @@ class ModuleSetName : public Module
 		ClientProtocol::Message msg("SETNAME", user);
 		msg.PushParamRef(real);
 		ClientProtocol::Event protoev(setnameevprov, msg);
-		IRCv3::WriteNeighborsWithCap(user, protoev, cmd.cap, true);
+		IRCv3::WriteNeighborsWithCap res(user, protoev, cmd.cap, true);
+		Monitor::WriteWatchersWithCap(monitorapi, user, protoev, cmd.cap, res.GetAlreadySentId());
 	}
 
 	Version GetVersion() CXX11_OVERRIDE
