@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013, 2018-2020, 2022 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2018-2020, 2022-2023 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
@@ -190,6 +190,11 @@ void TreeSocket::ProcessLine(std::string &line)
 			{
 				this->Capab(params);
 			}
+			else
+			{
+				ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Unknown command from fd %d in the WAIT_AUTH_2 phase: %s",
+					GetFd(), command.c_str());
+			}
 
 		break;
 		case CONNECTING:
@@ -212,7 +217,13 @@ void TreeSocket::ProcessLine(std::string &line)
 			{
 				this->Capab(params);
 			}
+			else
+			{
+				ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Unknown command from fd %d in the CONNECTING phase: %s",
+					GetFd(), command.c_str());
+			}
 		break;
+
 		case CONNECTED:
 			/*
 			 * State CONNECTED:
@@ -221,6 +232,7 @@ void TreeSocket::ProcessLine(std::string &line)
 			 */
 			this->ProcessConnectedLine(tags, prefix, command, params);
 		break;
+
 		case DYING:
 		break;
 	}
